summaryrefslogtreecommitdiffstats
path: root/aes.h
diff options
context:
space:
mode:
Diffstat (limited to 'aes.h')
-rw-r--r--aes.h13
1 files changed, 6 insertions, 7 deletions
diff --git a/aes.h b/aes.h
index e86ab7f..624b4ab 100644
--- a/aes.h
+++ b/aes.h
@@ -6,7 +6,7 @@
// #define the macros below to 1/0 to enable/disable the mode of operation.
//
// CBC enables AES128 encryption in CBC-mode of operation and handles 0-padding.
// ECB enables the basic ECB 16-byte block algorithm. Both can be enabled simultaneously.
// The #ifndef-guard allows it to be configured before #include'ing or at compile time.
@@ -18,23 +18,22 @@
#define ECB 1
#endif
-
+#define AES128
#if defined(ECB) && ECB
-void AES128_ECB_encrypt(const uint8_t* input, const uint8_t* key, uint8_t *output);
-void AES128_ECB_decrypt(const uint8_t* input, const uint8_t* key, uint8_t *output);
+void AES_ECB_encrypt(const uint8_t* input, const uint8_t* key, uint8_t *output, const uint32_t length);
+void AES_ECB_decrypt(const uint8_t* input, const uint8_t* key, uint8_t *output, const uint32_t length);
#endif // #if defined(ECB) && ECB
#if defined(CBC) && CBC
-void AES128_CBC_encrypt_buffer(uint8_t* output, uint8_t* input, uint32_t length, const uint8_t* key, const uint8_t* iv);
-void AES128_CBC_decrypt_buffer(uint8_t* output, uint8_t* input, uint32_t length, const uint8_t* key, const uint8_t* iv);
+void AES_CBC_encrypt_buffer(uint8_t* output, uint8_t* input, uint32_t length, const uint8_t* key, const uint8_t* iv);
+void AES_CBC_decrypt_buffer(uint8_t* output, uint8_t* input, uint32_t length, const uint8_t* key, const uint8_t* iv);
#endif // #if defined(CBC) && CBC
-
#endif //_AES_H_
@@ -6,7 +6,7 @@
// #define the macros below to 1/0 to enable/disable the mode of operation.
//
-// CBC enables AES128 encryption in CBC-mode of operation and handles 0-padding.
+// CBC enables AES encryption in CBC-mode of operation.
// ECB enables the basic ECB 16-byte block algorithm. Both can be enabled simultaneously.
// The #ifndef-guard allows it to be configured before #include'ing or at compile time.